/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.ajax.customizer;

import java.util.ArrayList;
import java.util.List;
import com.openexchange.tools.session.ServerSession;


/**
 * {@link AdditionalFieldsUtils} - Utility class for <code>AdditionalField</code>s.
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class AdditionalFieldsUtils {

    /**
     * Performs a bulk retrieval of passed field's values for given items.
     *
     * @param field The field from which to retrieve the values
     * @param items The items for which to retrieve the values
     * @param session The associated session
     * @return The values for given items
     */
    public static <T> List<Object> bulk(AdditionalField<T> field, List<T> items, ServerSession session) {
        List<Object> retval = new ArrayList<Object>(items.size());
        for (T item : items) {
            retval.add(field.getValue(item, session));
        }
        return retval;
    }

}
